import Link from "next/link";

import { Icons } from "@/components/icons";
import { TryAgain } from "@/components/try-again";
import { useHashtags } from "../hooks/use-hashtags";
import { Trend } from "./trend";

export const Trends = ({ title = "Trends" }: { title?: string }) => {
  const { data: hashtags, isLoading, isError, isSuccess } = useHashtags();

  if (hashtags && hashtags?.length <= 0) return null;

  return (
    <div className="">
      {isLoading ? (
        <div className="">
          <Icons.spinner className="h-4 w-4 animate-spin" />
        </div>
      ) : isError ? (
        <div className="">
          <TryAgain />
        </div>
      ) : (
        <>
          <div className="">
            <h1 className="">{title}</h1>
            {isSuccess &&
              hashtags?.map((hashtag, index) => {
                return (
                  <Trend
                    key={hashtag.id}
                    ranking={index + 1}
                    title={hashtag.text}
                    gweets={hashtag.score}
                  />
                );
              })}
          </div>
          <button className="">
            <Link href={`trends`}>Show more</Link>
          </button>
        </>
      )}
    </div>
  );
};
